@@ -1,9 +1,9 @@
 "anova.gam" <-
   function(object, ..., test = c("Chisq", "F", "Cp"))
 {
+  test=match.arg(test)
   margs <- function(...)
     nargs()
-  test <- match.arg(test)
   if(margs(...))
     anova.glmlist(list(object, ...), test = test)
   else summary.gam(object)$anova
